==> camel-api-3.4.1-sources.jar: org/apache/camel/health/HealthCheckRepository.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.health;

import java.util.Map;
import java.util.stream.Stream;

import org.apache.camel.spi.HasId;

/**
 * A repository for health checks.
 */
public interface HealthCheckRepository extends HasId {

    /**
     * Set if the checks associated to this repository is enabled or not.
     */
    boolean isEnabled();

    /**
     * Set if the checks associated to this repository is enabled or not.
     */
    void setEnabled(boolean enabled);

    /**
     * Configurations for health checks based on their ids
     */
    void setConfigurations(Map<String, HealthCheckConfiguration> configurations);

    /**
     * Configurations for health checks based on their ids
     */
    Map<String, HealthCheckConfiguration> getConfigurations();

    /**
     * Adds a health check configuration
     *
     * @param id             the health check id (can use patterns)
     * @param configuration  the configuration
     */
    void addConfiguration(String id, HealthCheckConfiguration configuration);

    /**
     * Returns a sequential {@code Stream} with the known {@link HealthCheck}
     * as its source.
     */
    Stream<HealthCheck> stream();
}

==> camel-api-3.14.7-sources.jar: org/apache/camel/health/HealthCheckRepository.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.health;

import java.util.Map;
import java.util.Optional;
import java.util.stream.Stream;

import org.apache.camel.spi.HasId;
import org.apache.camel.util.ObjectHelper;

/**
 * A repository for health checks.
 */
public interface HealthCheckRepository extends HasId {

    /**
     * Set if the checks associated to this repository is enabled or not.
     */
    boolean isEnabled();

    /**
     * Set if the checks associated to this repository is enabled or not.
     */
    void setEnabled(boolean enabled);

    /**
     * Configurations for health checks based on their ids
     */
    void setConfigurations(Map<String, HealthCheckConfiguration> configurations);

    /**
     * Configurations for health checks based on their ids
     */
    Map<String, HealthCheckConfiguration> getConfigurations();

    /**
     * Adds a health check configuration
     *
     * @param id            the health check id (can use patterns)
     * @param configuration the configuration
     */
    void addConfiguration(String id, HealthCheckConfiguration configuration);

    /**
     * Returns a sequential {@code Stream} with the known {@link HealthCheck} as its source.
     */
    Stream<HealthCheck> stream();

    /**
     * Returns the check identified by the given <code>id</code> if available.
     */
    default Optional<HealthCheck> getCheck(String id) {
        return stream()
                .filter(r -> ObjectHelper.equal(r.getId(), id)
                        || ObjectHelper.equal(r.getId().replace("-health-check", ""), id)
                        || ObjectHelper.equal(r.getId().replace("route:", ""), id))
                .findFirst();
    }
}
